@@ -8,7 +8,8 @@ from weather_in import __version__, api_key
 def main():
     city = sys.argv[1]
     state = sys.argv[2]
-    url = "https://api.openweathermap.org/data/2.5/weather?q=%s,%s&appid=%s&units=imperial" % (city, state, api_key)
+    country = sys.argv[3]
+    url = "https://api.openweathermap.org/data/2.5/weather?q=%s,%s,%s&appid=%s&units=imperial" % (city, state, country, api_key)
     try:
         response = requests.get(url)
         data = json.loads(response.text)
